/*
 * An object providing access to directory functionality.
 *
 * Copyright (C) 2021 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include "directory_provider.h"
#include "directory_resource.h"



/* Initialise the provider. */

DirectoryProvider::DirectoryProvider(fileid_t fileid,
                                     ProviderRegistry *registry,
                                     DirectoryAccessor *accessor)
: Provider(fileid, registry), _accessor(accessor)
{
}

/* Deallocate the provider's resources. */

DirectoryProvider::~DirectoryProvider()
{
}

/* Return the accessor. */

DirectoryAccessor *DirectoryProvider::accessor()
{
    return _accessor;
}

/* Return a directory resource initialised with this provider. */

long DirectoryProvider::make_resource(offset_t *size,
                                      object_flags_t *object_flags,
                                      Resource **resource)
{
    /* Provide non-file values for certain outputs. */

    *size = 0;
    *object_flags = 0;

    /* Initialise the resource with the provider and a reference to the registry
       for detaching from the provider. */

    this->attach();
    *resource = new DirectoryResource(_fileid, this);
    return L4_EOK;
}

// vim: tabstop=4 expandtab shiftwidth=4
